package com.imagine.component.calendar.demo;

import java.util.*;

import javax.swing.UIManager;

import com.imagine.component.calendar.demo.panels.mainfeatures.*;
import com.imagine.component.calendar.renderers.*;
import com.imagine.component.calendar.selection.*;
import com.imagine.component.calendar.skins.styles.*;

public class CalendarDemoController {
  
  private Date date = null;
  
  private Locale[] locales = Locale.getAvailableLocales();
  
  private CalendarRendererProvider[] calendarRendererProviders = { 
      new CalendarRendererProviderDefault(), 
      new CalendarRendererProviderOval(), 
      new CalendarRendererProviderRoundRect(), 
      new CalendarRendererProviderHoveredLine(), 
      new CalendarRendererProviderHoveredColumn(), 
      new CalendarRendererProviderHoveredIntersection(), 
  };
  
  private CalendarSelectionModel[] calendarSelectionModels = { 
	      new CalendarSelectionModelSingleSelection(), 
	      new CalendarSelectionModelSingleIntervalSelection(), 
	      new CalendarSelectionModelMultipleIntervalSelection(), 
	      new CalendarSelectionModelDisabledWeekends(),
	  };
	  
  private CalendarSkinStyle[] skinStyles = {
    new CalendarSkinStyleDefault(),
    new CalendarSkinStyleForest(),
    new CalendarSkinStyleAqua(),
    new CalendarSkinStyleLight(),
    new CalendarSkinStyleDark(),
    new CalendarSkinStyleCustomBackgroundImage(),
    new CalendarSkinStyleCustomCellImage(),
  };
  
  private String systemLookAndFeel = UIManager.getSystemLookAndFeelClassName();
  
  UIManager.LookAndFeelInfo[] lookAndFeelInfos = UIManager.getInstalledLookAndFeels();
  
  private CalendarDemo calendarDemo;
  
  public CalendarDemoController(CalendarDemo calendarDemo) {
    this.calendarDemo = calendarDemo;
    
    try {
      UIManager.setLookAndFeel(systemLookAndFeel);
    } catch (Exception e) {
    }
  }
  
  
  public Date getDate() {
    return date;
  }
  
  public void setDate(Date date) {
    this.date = date;
  }
  
  public Locale[] getLocales() {
    return locales;
  }
  
  public CalendarRendererProvider[] getCalendarRendererProviders() {
    return calendarRendererProviders;
  }
  
  public CalendarSkinStyle[] getSkinStyles() {
    return skinStyles;
  }
  
  public String getSystemLookAndFeel() {
    return systemLookAndFeel;
  }
  
  public UIManager.LookAndFeelInfo[] getLookAndFeelInfos() {
    return lookAndFeelInfos;
  }
  
  public CalendarDemo getCalendarDemo() {
    return calendarDemo;
  }

  public CalendarSelectionModel[] getCalendarSelectionModels() {
	  return calendarSelectionModels;
  }
}
