package com.imagine.component.calendar.demo.panels.mainfeatures;

import java.awt.*;
import java.awt.event.*;
import java.util.*;

import javax.swing.*;

import com.imagine.component.calendar.*;
import com.imagine.component.calendar.demo.CalendarDemoController;
import com.imagine.component.calendar.demo.panels.CalendarDemoPanel;
import com.imagine.component.calendar.events.*;
import com.imagine.component.calendar.renderers.CalendarRendererProvider;
import com.imagine.component.calendar.selection.*;
import com.imagine.component.calendar.util.CalendarUtils;

public class CalendarDemoPanelMainFeatures extends CalendarDemoPanel {
  
  private CalendarFactory calendarFactory = CalendarFactory.getInstance();
  
  private CalendarComponent calendarComponent = calendarFactory.createCalendarComponent(new Date());
  
  private CalendarComboBox calendarComboBox = calendarFactory.createCalendarComboBox(new Date());
  
  private String[] monthsNames = CalendarUtils.getMonthsNames(Locale.ENGLISH);
  
  private String[] weekDays = CalendarUtils.getDaysNames(Locale.ENGLISH, CalendarUtils.getWeekDaysCodes()[0]);
  
  private Integer[] maxWeekDaysNamesLength = {
      new Integer(1),
      new Integer(2),
      new Integer(3),
      new Integer(9),
  };
  
  private Integer[] maxMonthsNamesLength = {
      new Integer(15),
      new Integer(5),
      new Integer(3),
      new Integer(1),
  };
  
  private JLabel chosenDateText = null;
  
  private JLabel weekStartsOnText = null;
  
  private JComboBox weekStartsOnValue = null;
  
  private JLabel showGridText = null;
  
  private JCheckBox showGridValue = null;
  
  private JLabel showWeekText = null;

  private JCheckBox showWeekValue = null;

  private JLabel emptySelectionAllowedText = null;

  private JCheckBox emptySelectionAllowedValue = null;
  
  private JLabel showHoverText = null;

  private JCheckBox showHoverValue = null;
  
  private JLabel showStatusPanelText = null;

  private JCheckBox showStatusPanelValue = null;
  
  private JLabel extraMonthDaysVisibleText = null;
  
  private JCheckBox extraMonthDaysVisibleValue = null;
  
  private JLabel calendarRendererProvidersText = null;
  
  private JComboBox calendarRendererProvidersValue = null;
  
  private JLabel calendarSelectionModelsText = null;
  
  private JComboBox calendarSelectionModelsValue = null;
  
  private JLabel skinText = null;
  
  private JComboBox skinValue = null;
  
  private JLabel maxWeekDaysNamesLengthText = null;
  
  private JComboBox maxWeekDaysNamesLengthValue = null;
  
  private JLabel maxMonthsNamesLengthText = null;
  
  private JComboBox maxMonthsNamesLengthValue = null;
  
  private JLabel localeText = null;
  
  private JComboBox localeValue = null;
  
  private JLabel comboBoxCloseWhenDateSelectedText = null;
  
  private JCheckBox comboBoxCloseWhenDateSelectedValue = null;
  
  private JPanel eventsPanel = null;
  
  private JScrollPane eventsScrollPane = null;
  
  private JTextArea eventsTextArea = null;
  
  
  public CalendarDemoPanelMainFeatures(CalendarDemoController calendarDemoController) {
    super(calendarDemoController);
    
    try {
      initialize();
    } catch (Exception e) {
    	e.printStackTrace(System.out);
    }
  }
  
  
  public void initialize() {
    
    calendarComboBox.setDateFormat("dd MMMMMMMMMM yyyy");
    
    CustomTable customTable = new CustomTable();
    final CalendarComboBox customTableCalendarComboBox = customTable.calendarTableCellEditor.getCalendarComboBox();
    
    eventsTextArea = new JTextArea();
    eventsTextArea.setRows(4);
    eventsTextArea.setColumns(20);
    eventsTextArea.setWrapStyleWord(true);
    
    // Chosen date.
    
    chosenDateText = new JLabel("Date:");
    calendarComboBox.setDate(calendarComponent.getDate());
    chosenDateText.setDisplayedMnemonic('D');
    chosenDateText.setLabelFor(calendarComboBox.getComboBoxComponent());
    
    // Week starts on.
    
    weekStartsOnValue = new JComboBox(weekDays);
    weekStartsOnValue.addItemListener(new ItemListener() {
      public void itemStateChanged(ItemEvent itemEvent) {
        if (itemEvent.getStateChange() == ItemEvent.SELECTED) {
          JComboBox source = ((JComboBox)itemEvent.getSource());
          int selectedIndex = source.getSelectedIndex();
          if (selectedIndex < 0 || selectedIndex >= source.getItemCount()) {
            selectedIndex = 0;
          }
          calendarComponent.setCalendarProperty(CalendarComponent.FIRST_DAY_OF_WEEK, new Integer(CalendarUtils.getWeekDaysCodes()[selectedIndex]));
          calendarComboBox.getCalendarComponent().setCalendarProperty(CalendarComponent.FIRST_DAY_OF_WEEK, new Integer(CalendarUtils.getWeekDaysCodes()[selectedIndex]));
          customTableCalendarComboBox.getCalendarComponent().setCalendarProperty(CalendarComponent.FIRST_DAY_OF_WEEK, new Integer(CalendarUtils.getWeekDaysCodes()[selectedIndex]));
          calendarDemoController.getCalendarDemo().getFrame().pack();
        }
      }
    });
    weekStartsOnValue.setRenderer(new DefaultListCellRenderer() {
      public Component getListCellRendererComponent(JList list, Object value, int index, boolean isSelected, boolean cellHasFocus) {
        Component label = super.getListCellRendererComponent(list, value, index, isSelected, cellHasFocus);
        
        if (value != null) {
          setText(value.toString());
        }
        
        return label;
      }
    });
    calendarComponent.setCalendarProperty(CalendarComponent.FIRST_DAY_OF_WEEK, new Integer(CalendarUtils.getWeekDaysCodes()[0]));
    calendarComboBox.getCalendarComponent().setCalendarProperty(CalendarComponent.FIRST_DAY_OF_WEEK, new Integer(CalendarUtils.getWeekDaysCodes()[0]));
    customTableCalendarComboBox.getCalendarComponent().setCalendarProperty(CalendarComponent.FIRST_DAY_OF_WEEK, new Integer(CalendarUtils.getWeekDaysCodes()[0]));
    
    weekStartsOnText = new JLabel("Week Starts On:");
    weekStartsOnText.setDisplayedMnemonic('W');
    weekStartsOnText.setLabelFor(weekStartsOnValue);
    
    // selected calendar renderer provider
    
    calendarRendererProvidersValue = new JComboBox(calendarDemoController.getCalendarRendererProviders());
    calendarRendererProvidersValue.addItemListener(new ItemListener() {
      public void itemStateChanged(ItemEvent itemEvent) {
        if (itemEvent.getStateChange() == ItemEvent.SELECTED) {
          JComboBox source = ((JComboBox)itemEvent.getSource());
          int selectedIndex = source.getSelectedIndex();
          if (selectedIndex < 0 || selectedIndex >= source.getItemCount()) {
            selectedIndex = 0;
          }
          CalendarRendererProvider calendarRendererProvider = (CalendarRendererProvider)calendarDemoController.getCalendarRendererProviders()[selectedIndex];
          updateRendererProvider(calendarComponent, calendarRendererProvider);
          updateRendererProvider(calendarComboBox.getCalendarComponent(), calendarRendererProvider);
          updateRendererProvider(customTableCalendarComboBox.getCalendarComponent(), calendarRendererProvider);
          calendarDemoController.getCalendarDemo().getFrame().pack();
        }
      }
    });
    calendarRendererProvidersValue.setRenderer(new DefaultListCellRenderer() {
      public Component getListCellRendererComponent(JList list, Object value, int index, boolean isSelected, boolean cellHasFocus) {
        Component label = super.getListCellRendererComponent(list, value, index, isSelected, cellHasFocus);
        
        if (value != null) {
          setText(value.toString());
        }
        
        return label;
      }
    });
    CalendarRendererProvider calendarRendererProvider = (CalendarRendererProvider)calendarDemoController.getCalendarRendererProviders()[0];
    updateRendererProvider(calendarComponent, calendarRendererProvider);
    updateRendererProvider(calendarComboBox.getCalendarComponent(), calendarRendererProvider);
    updateRendererProvider(customTableCalendarComboBox.getCalendarComponent(), calendarRendererProvider);
    
    calendarRendererProvidersText = new JLabel("Calendar Renderer Provider:");
    calendarRendererProvidersText.setDisplayedMnemonic('R');
    calendarRendererProvidersText.setLabelFor(calendarRendererProvidersValue);
    
    //show grid
    
    showGridValue = new JCheckBox();
    showGridValue.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
        calendarComponent.setCalendarProperty(CalendarComponent.SHOW_GRID, new Boolean(showGridValue.isSelected()));
        calendarComboBox.getCalendarComponent().setCalendarProperty(CalendarComponent.SHOW_GRID, new Boolean(showGridValue.isSelected()));
        customTableCalendarComboBox.getCalendarComponent().setCalendarProperty(CalendarComponent.SHOW_GRID, new Boolean(showGridValue.isSelected()));
        calendarDemoController.getCalendarDemo().getFrame().pack();
      }
    });
    calendarComponent.setCalendarProperty(CalendarComponent.SHOW_GRID, new Boolean(showGridValue.isSelected()));
    calendarComboBox.getCalendarComponent().setCalendarProperty(CalendarComponent.SHOW_GRID, new Boolean(showGridValue.isSelected()));
    customTableCalendarComboBox.getCalendarComponent().setCalendarProperty(CalendarComponent.SHOW_GRID, new Boolean(showGridValue.isSelected()));
    
    showGridText = new JLabel("Show Grid:");
    showGridText.setDisplayedMnemonic('S');
    showGridText.setLabelFor(showGridValue);
    
    
    //extra month days
    
    extraMonthDaysVisibleValue = new JCheckBox();
    extraMonthDaysVisibleValue.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
        calendarComponent.setCalendarProperty(CalendarComponent.SHOW_EXTRA_MONTH_DAYS, new Boolean(extraMonthDaysVisibleValue.isSelected()));
        calendarComboBox.getCalendarComponent().setCalendarProperty(CalendarComponent.SHOW_EXTRA_MONTH_DAYS, new Boolean(extraMonthDaysVisibleValue.isSelected()));
        customTableCalendarComboBox.getCalendarComponent().setCalendarProperty(CalendarComponent.SHOW_EXTRA_MONTH_DAYS, new Boolean(extraMonthDaysVisibleValue.isSelected()));
        calendarDemoController.getCalendarDemo().getFrame().pack();
      }
    });
    extraMonthDaysVisibleValue.setSelected(true);
    calendarComponent.setCalendarProperty(CalendarComponent.SHOW_EXTRA_MONTH_DAYS, new Boolean(extraMonthDaysVisibleValue.isSelected()));
    calendarComboBox.getCalendarComponent().setCalendarProperty(CalendarComponent.SHOW_EXTRA_MONTH_DAYS, new Boolean(extraMonthDaysVisibleValue.isSelected()));
    customTableCalendarComboBox.getCalendarComponent().setCalendarProperty(CalendarComponent.SHOW_EXTRA_MONTH_DAYS, new Boolean(extraMonthDaysVisibleValue.isSelected()));
    
    extraMonthDaysVisibleText = new JLabel("Show Extra Month Days:");
    extraMonthDaysVisibleText.setDisplayedMnemonic('E');
    extraMonthDaysVisibleText.setLabelFor(extraMonthDaysVisibleValue);
    
    
    //show week

    showWeekValue = new JCheckBox();
    showWeekValue.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
        calendarComponent.setCalendarProperty(CalendarComponent.SHOW_WEEK, new Boolean(showWeekValue.isSelected()));
        calendarComboBox.getCalendarComponent().setCalendarProperty(CalendarComponent.SHOW_WEEK, new Boolean(showWeekValue.isSelected()));
        customTableCalendarComboBox.getCalendarComponent().setCalendarProperty(CalendarComponent.SHOW_WEEK, new Boolean(showWeekValue.isSelected()));
        calendarDemoController.getCalendarDemo().getFrame().pack();
      }
    });
    calendarComponent.setCalendarProperty(CalendarComponent.SHOW_WEEK, new Boolean(showWeekValue.isSelected()));
    calendarComboBox.getCalendarComponent().setCalendarProperty(CalendarComponent.SHOW_WEEK, new Boolean(showWeekValue.isSelected()));
    customTableCalendarComboBox.getCalendarComponent().setCalendarProperty(CalendarComponent.SHOW_WEEK, new Boolean(showWeekValue.isSelected()));

    showWeekText = new JLabel("Show Week:");
    showWeekText.setDisplayedMnemonic('W');
    showWeekText.setLabelFor(showWeekValue);

    //show hover

    showHoverValue = new JCheckBox();
    showHoverValue.setSelected(true);
    showHoverValue.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
        calendarComponent.setCalendarProperty(CalendarComponent.SHOW_HOVER, new Boolean(showHoverValue.isSelected()));
        calendarComboBox.getCalendarComponent().setCalendarProperty(CalendarComponent.SHOW_HOVER, new Boolean(showHoverValue.isSelected()));
        customTableCalendarComboBox.getCalendarComponent().setCalendarProperty(CalendarComponent.SHOW_HOVER, new Boolean(showHoverValue.isSelected()));
        calendarDemoController.getCalendarDemo().getFrame().pack();
      }
    });
    calendarComponent.setCalendarProperty(CalendarComponent.SHOW_HOVER, new Boolean(showHoverValue.isSelected()));
    calendarComboBox.getCalendarComponent().setCalendarProperty(CalendarComponent.SHOW_HOVER, new Boolean(showHoverValue.isSelected()));
    customTableCalendarComboBox.getCalendarComponent().setCalendarProperty(CalendarComponent.SHOW_HOVER, new Boolean(showHoverValue.isSelected()));

    showHoverText = new JLabel("Show Hover:");
    showHoverText.setDisplayedMnemonic('H');
    showHoverText.setLabelFor(showHoverValue);

    //empty selection allowed

    emptySelectionAllowedValue = new JCheckBox();
    emptySelectionAllowedValue.setSelected(true);
    emptySelectionAllowedValue.addActionListener(new ActionListener() {
    	public void actionPerformed(ActionEvent e) {
    		boolean code = true;
    		if (code) {
    			code = updateEmptySelectionAllowed(calendarComponent, "CalendarComponent");
    		}
    		if (code) {
    			code = updateEmptySelectionAllowed(calendarComboBox.getCalendarComponent(), "CalendarComboBox");
    		}
    		if (code) {
    			code = updateEmptySelectionAllowed(customTableCalendarComboBox.getCalendarComponent(), "TableCalendarComboBox");
    		}
    		calendarDemoController.getCalendarDemo().getFrame().pack();
    	}
    });
	boolean code = true;
	if (code) {
		code = updateEmptySelectionAllowed(calendarComponent, "CalendarComponent");
	}
	if (code) {
		code = updateEmptySelectionAllowed(calendarComboBox.getCalendarComponent(), "CalendarComboBox");
	}
	if (code) {
		code = updateEmptySelectionAllowed(customTableCalendarComboBox.getCalendarComponent(), "TableCalendarComboBox");
	}
    
    emptySelectionAllowedText = new JLabel("Empty Selection Allowed:");
    emptySelectionAllowedText.setDisplayedMnemonic('A');
    emptySelectionAllowedText.setLabelFor(emptySelectionAllowedValue);
    
    //show status panel

    showStatusPanelValue = new JCheckBox();
    showStatusPanelValue.setSelected(true);
    showStatusPanelValue.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
        calendarComponent.setCalendarProperty(CalendarComponent.SHOW_STATUS_PANEL, new Boolean(showStatusPanelValue.isSelected()));
        calendarComboBox.getCalendarComponent().setCalendarProperty(CalendarComponent.SHOW_STATUS_PANEL, new Boolean(showStatusPanelValue.isSelected()));
        customTableCalendarComboBox.getCalendarComponent().setCalendarProperty(CalendarComponent.SHOW_STATUS_PANEL, new Boolean(showStatusPanelValue.isSelected()));
        calendarDemoController.getCalendarDemo().getFrame().pack();
      }
    });
    calendarComponent.setCalendarProperty(CalendarComponent.SHOW_STATUS_PANEL, new Boolean(showStatusPanelValue.isSelected()));
    calendarComboBox.getCalendarComponent().setCalendarProperty(CalendarComponent.SHOW_STATUS_PANEL, new Boolean(showStatusPanelValue.isSelected()));
    customTableCalendarComboBox.getCalendarComponent().setCalendarProperty(CalendarComponent.SHOW_STATUS_PANEL, new Boolean(showStatusPanelValue.isSelected()));

    showStatusPanelText = new JLabel("Show Status Panel:");
    showStatusPanelText.setDisplayedMnemonic('P');
    showStatusPanelText.setLabelFor(showStatusPanelValue);

    // skins
    
    skinValue = new JComboBox(calendarDemoController.getSkinStyles());
    skinValue.addItemListener(new ItemListener() {
      public void itemStateChanged(ItemEvent itemEvent) {
        if (itemEvent.getStateChange() == ItemEvent.SELECTED) {
          JComboBox source = ((JComboBox)itemEvent.getSource());
          int selectedIndex = source.getSelectedIndex();
          if (selectedIndex < 0 || selectedIndex >= source.getItemCount()) {
            selectedIndex = 0;
          }
          try {
            calendarComponent.getCalendarSkin().applyCalendarSkinStyle(calendarDemoController.getSkinStyles()[selectedIndex]);
            calendarComboBox.getCalendarComponent().getCalendarSkin().applyCalendarSkinStyle(calendarDemoController.getSkinStyles()[selectedIndex]);
            customTableCalendarComboBox.getCalendarComponent().getCalendarSkin().applyCalendarSkinStyle(calendarDemoController.getSkinStyles()[selectedIndex]);
          } catch (Exception e) {
          }
          calendarDemoController.getCalendarDemo().getFrame().pack();
        }
      }
    });
    skinValue.setRenderer(new DefaultListCellRenderer() {
      public Component getListCellRendererComponent(JList list, Object value, int index, boolean isSelected, boolean cellHasFocus) {
        Component label = super.getListCellRendererComponent(list, value, index, isSelected, cellHasFocus);
        
        if (value != null) {
          setText(value.toString());
        }
        
        return label;
      }
    });
    calendarComponent.getCalendarSkin().applyCalendarSkinStyle(calendarDemoController.getSkinStyles()[0]);
    calendarComboBox.getCalendarComponent().getCalendarSkin().applyCalendarSkinStyle(calendarDemoController.getSkinStyles()[0]);
    customTableCalendarComboBox.getCalendarComponent().getCalendarSkin().applyCalendarSkinStyle(calendarDemoController.getSkinStyles()[0]);
    
    skinText = new JLabel("Skin Style:");
    skinText.setDisplayedMnemonic('y');
    skinText.setLabelFor(skinValue);
    
    // Max Week Days Names Length
    
    maxWeekDaysNamesLengthValue = new JComboBox(maxWeekDaysNamesLength);
    maxWeekDaysNamesLengthValue.addItemListener(new ItemListener() {
      public void itemStateChanged(ItemEvent itemEvent) {
        if (itemEvent.getStateChange() == ItemEvent.SELECTED) {
          JComboBox source = ((JComboBox)itemEvent.getSource());
          int selectedIndex = source.getSelectedIndex();
          if (selectedIndex < 0 || selectedIndex >= source.getItemCount()) {
            selectedIndex = 0;
          }
          calendarComponent.setCalendarProperty(CalendarComponent.MAX_WEEK_DAYS_NAMES_LENGTH, maxWeekDaysNamesLength[selectedIndex]);
          calendarComboBox.getCalendarComponent().setCalendarProperty(CalendarComponent.MAX_WEEK_DAYS_NAMES_LENGTH, maxWeekDaysNamesLength[selectedIndex]);
          customTableCalendarComboBox.getCalendarComponent().setCalendarProperty(CalendarComponent.MAX_WEEK_DAYS_NAMES_LENGTH, maxWeekDaysNamesLength[selectedIndex]);
          calendarDemoController.getCalendarDemo().getFrame().pack();
        }
      }
    });
    maxWeekDaysNamesLengthValue.setRenderer(new DefaultListCellRenderer() {
      public Component getListCellRendererComponent(JList list, Object value, int index, boolean isSelected, boolean cellHasFocus) {
        Component label = super.getListCellRendererComponent(list, value, index, isSelected, cellHasFocus);
        
        if (value != null) {
          setText(value.toString());
        }
        
        return label;
      }
    });
    calendarComponent.setCalendarProperty(CalendarComponent.MAX_WEEK_DAYS_NAMES_LENGTH, maxWeekDaysNamesLength[0]);
    calendarComboBox.getCalendarComponent().setCalendarProperty(CalendarComponent.MAX_WEEK_DAYS_NAMES_LENGTH, maxWeekDaysNamesLength[0]);
    customTableCalendarComboBox.getCalendarComponent().setCalendarProperty(CalendarComponent.MAX_WEEK_DAYS_NAMES_LENGTH, maxWeekDaysNamesLength[0]);
    
    maxWeekDaysNamesLengthText = new JLabel("Max Week Days Length:");
    maxWeekDaysNamesLengthText.setDisplayedMnemonic('M');
    maxWeekDaysNamesLengthText.setLabelFor(maxWeekDaysNamesLengthValue);
    
    
    // Max Months Names Length
    
    maxMonthsNamesLengthValue = new JComboBox(maxMonthsNamesLength);
    maxMonthsNamesLengthValue.addItemListener(new ItemListener() {
      public void itemStateChanged(ItemEvent itemEvent) {
        if (itemEvent.getStateChange() == ItemEvent.SELECTED) {
          JComboBox source = ((JComboBox)itemEvent.getSource());
          int selectedIndex = source.getSelectedIndex();
          if (selectedIndex < 0 || selectedIndex >= source.getItemCount()) {
            selectedIndex = 0;
          }
          calendarComponent.setCalendarProperty(CalendarComponent.MAX_MONTHS_NAMES_LENGTH, maxMonthsNamesLength[selectedIndex]);
          calendarComboBox.getCalendarComponent().setCalendarProperty(CalendarComponent.MAX_MONTHS_NAMES_LENGTH, maxMonthsNamesLength[selectedIndex]);
          customTableCalendarComboBox.getCalendarComponent().setCalendarProperty(CalendarComponent.MAX_MONTHS_NAMES_LENGTH, maxMonthsNamesLength[selectedIndex]);
          calendarDemoController.getCalendarDemo().getFrame().pack();
        }
      }
    });
    maxMonthsNamesLengthValue.setRenderer(new DefaultListCellRenderer() {
      public Component getListCellRendererComponent(JList list, Object value, int index, boolean isSelected, boolean cellHasFocus) {
        Component label = super.getListCellRendererComponent(list, value, index, isSelected, cellHasFocus);
        
        if (value != null) {
          setText(value.toString());
        }
        
        return label;
      }
    });
    calendarComponent.setCalendarProperty(CalendarComponent.MAX_MONTHS_NAMES_LENGTH, maxMonthsNamesLength[0]);
    calendarComboBox.getCalendarComponent().setCalendarProperty(CalendarComponent.MAX_MONTHS_NAMES_LENGTH, maxMonthsNamesLength[0]);
    customTableCalendarComboBox.getCalendarComponent().setCalendarProperty(CalendarComponent.MAX_MONTHS_NAMES_LENGTH, maxMonthsNamesLength[0]);
    
    maxMonthsNamesLengthText = new JLabel("Max Months Names Length:");
    maxMonthsNamesLengthText.setDisplayedMnemonic('M');
    maxMonthsNamesLengthText.setLabelFor(maxMonthsNamesLengthValue);
    
    // Locale
    
    localeValue = new JComboBox(calendarDemoController.getLocales());
    localeValue.addItemListener(new ItemListener() {
      public void itemStateChanged(ItemEvent itemEvent) {
        if (itemEvent.getStateChange() == ItemEvent.SELECTED) {
          JComboBox source = ((JComboBox)itemEvent.getSource());
          int selectedIndex = source.getSelectedIndex();
          if (selectedIndex < 0 || selectedIndex >= source.getItemCount()) {
            selectedIndex = 0;
          }
          calendarComponent.setCalendarProperty(CalendarComponent.LOCALE, calendarDemoController.getLocales()[selectedIndex]);
          calendarComboBox.getCalendarComponent().setCalendarProperty(CalendarComponent.LOCALE, calendarDemoController.getLocales()[selectedIndex]);
          customTableCalendarComboBox.getCalendarComponent().setCalendarProperty(CalendarComponent.LOCALE, calendarDemoController.getLocales()[selectedIndex]);
          calendarDemoController.getCalendarDemo().getFrame().pack();
        }
      }
    });
    localeValue.setRenderer(new DefaultListCellRenderer() {
      public Component getListCellRendererComponent(JList list, Object value, int index, boolean isSelected, boolean cellHasFocus) {
        Component label = super.getListCellRendererComponent(list, value, index, isSelected, cellHasFocus);
        
        if (value != null) {
          Locale locale = (Locale) value;
          setText(locale.getDisplayName());
        }
        
        return label;
      }
    });
    localeValue.setSelectedItem(calendarComponent.getLocaleCalendarProperty(CalendarComponent.LOCALE));
    
    localeText = new JLabel("Locale:");
    localeText.setDisplayedMnemonic('L');
    localeText.setLabelFor(localeValue);
    
    
    // selected selection models
    
    calendarSelectionModelsValue = new JComboBox(calendarDemoController.getCalendarSelectionModels());
    calendarSelectionModelsValue.addItemListener(new ItemListener() {
      public void itemStateChanged(ItemEvent itemEvent) {
        if (itemEvent.getStateChange() == ItemEvent.SELECTED) {
          JComboBox source = ((JComboBox)itemEvent.getSource());
          int selectedIndex = source.getSelectedIndex();
          if (selectedIndex < 0 || selectedIndex >= source.getItemCount()) {
            selectedIndex = 0;
          }
          CalendarSelectionModel calendarSelectionModel = (CalendarSelectionModel)calendarDemoController.getCalendarSelectionModels()[selectedIndex];
    	  updateSelectionModel(calendarComponent, calendarSelectionModel);
    	  updateSelectionModel(calendarComboBox.getCalendarComponent(), calendarSelectionModel);
    	  updateSelectionModel(customTableCalendarComboBox.getCalendarComponent(), calendarSelectionModel);
          calendarDemoController.getCalendarDemo().getFrame().pack();
        }
      }
    });
    calendarSelectionModelsValue.setRenderer(new DefaultListCellRenderer() {
      public Component getListCellRendererComponent(JList list, Object value, int index, boolean isSelected, boolean cellHasFocus) {
        Component label = super.getListCellRendererComponent(list, value, index, isSelected, cellHasFocus);
        
        if (value != null) {
          setText(value.toString());
        }
        
        return label;
      }
    });
    CalendarSelectionModel calendarSelectionModel = (CalendarSelectionModel)calendarDemoController.getCalendarSelectionModels()[0];
    updateSelectionModel(calendarComponent, calendarSelectionModel);
    updateSelectionModel(calendarComboBox.getCalendarComponent(), calendarSelectionModel);
    updateSelectionModel(customTableCalendarComboBox.getCalendarComponent(), calendarSelectionModel);
    calendarSelectionModelsText = new JLabel("Calendar Selection Model:");
    calendarSelectionModelsText.setDisplayedMnemonic('M');
    calendarSelectionModelsText.setLabelFor(calendarSelectionModelsValue);
    
    eventsPanel = new JPanel();
    eventsScrollPane = new JScrollPane(eventsTextArea);
    eventsScrollPane.setVerticalScrollBarPolicy(JScrollPane.VERTICAL_SCROLLBAR_ALWAYS);
    eventsScrollPane.setHorizontalScrollBarPolicy(JScrollPane.HORIZONTAL_SCROLLBAR_AS_NEEDED);
    
    eventsPanel.setBorder(BorderFactory.createTitledBorder("Events"));
    eventsPanel.setLayout(new GridBagLayout());
    eventsPanel.add(eventsScrollPane, new GridBagConstraints(0, 0, 1, 1, 1, 1, GridBagConstraints.NORTHWEST, GridBagConstraints.BOTH, new Insets(5, 5, 5, 5), 0, 0));
    
    // Start puting the components together.
    
    JPanel leftPanel = new JPanel();
    JPanel datePanel = new JPanel();
    JPanel chosenDatePanel = new JPanel();
    JPanel tablePanel = new JPanel();
    JPanel calendarPropertiesPanel = new JPanel();
    JPanel calendarPropertiesLeftPanel = new JPanel();
    JPanel calendarPropertiesRightPanel = new JPanel();
    JPanel comboboxPropertiesPanel = new JPanel();
    
    
    int count = 0;
    calendarPropertiesLeftPanel.setLayout(new GridBagLayout());
    calendarPropertiesLeftPanel.add(weekStartsOnText, new GridBagConstraints(0, count, 1, 1, 0, 0, GridBagConstraints.NORTHEAST, GridBagConstraints.NONE, new Insets(5, 5, 5, 5), 0, 0));
    calendarPropertiesLeftPanel.add(weekStartsOnValue, new GridBagConstraints(1, count, 1, 1, 1, 0, GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 5, 5), 0, 0));
    count++;
    calendarPropertiesLeftPanel.add(showGridText, new GridBagConstraints(0, count, 1, 1, 0, 0, GridBagConstraints.NORTHEAST, GridBagConstraints.NONE, new Insets(5, 5, 5, 5), 0, 0));
    calendarPropertiesLeftPanel.add(showGridValue, new GridBagConstraints(1, count, 1, 1, 1, 0, GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 5, 5), 0, 0));
    count++;
    calendarPropertiesLeftPanel.add(showWeekText, new GridBagConstraints(0, count, 1, 1, 0, 0, GridBagConstraints.NORTHEAST, GridBagConstraints.NONE, new Insets(5, 5, 5, 5), 0, 0));
    calendarPropertiesLeftPanel.add(showWeekValue, new GridBagConstraints(1, count, 1, 1, 1, 0, GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 5, 5), 0, 0));
    count++;
    calendarPropertiesLeftPanel.add(showHoverText, new GridBagConstraints(0, count, 1, 1, 0, 0, GridBagConstraints.NORTHEAST, GridBagConstraints.NONE, new Insets(5, 5, 5, 5), 0, 0));
    calendarPropertiesLeftPanel.add(showHoverValue, new GridBagConstraints(1, count, 1, 1, 1, 0, GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 5, 5), 0, 0));
    count++;
    calendarPropertiesLeftPanel.add(extraMonthDaysVisibleText, new GridBagConstraints(0, count, 1, 1, 0, 0, GridBagConstraints.NORTHEAST, GridBagConstraints.NONE, new Insets(5, 5, 5, 5), 0, 0));
    calendarPropertiesLeftPanel.add(extraMonthDaysVisibleValue, new GridBagConstraints(1, count, 1, 1, 1, 0, GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 5, 5), 0, 0));
    count++;
    calendarPropertiesLeftPanel.add(showStatusPanelText, new GridBagConstraints(0, count, 1, 1, 0, 0, GridBagConstraints.NORTHEAST, GridBagConstraints.NONE, new Insets(5, 5, 5, 5), 0, 0));
    calendarPropertiesLeftPanel.add(showStatusPanelValue, new GridBagConstraints(1, count, 1, 1, 1, 0, GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 5, 5), 0, 0));
    count++;
    calendarPropertiesLeftPanel.add(emptySelectionAllowedText, new GridBagConstraints(0, count, 1, 1, 0, 0, GridBagConstraints.NORTHEAST, GridBagConstraints.NONE, new Insets(5, 5, 5, 5), 0, 0));
    calendarPropertiesLeftPanel.add(emptySelectionAllowedValue, new GridBagConstraints(1, count, 1, 1, 1, 0, GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 5, 5), 0, 0));
    count++;
    calendarPropertiesLeftPanel.add(calendarRendererProvidersText, new GridBagConstraints(0, count, 1, 1, 0, 0, GridBagConstraints.NORTHEAST, GridBagConstraints.NONE, new Insets(5, 5, 5, 5), 0, 0));
    calendarPropertiesLeftPanel.add(calendarRendererProvidersValue, new GridBagConstraints(1, count, 1, 1, 1, 0, GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 5, 5), 0, 0));
    count++;
    calendarPropertiesLeftPanel.add(skinText, new GridBagConstraints(0, count, 1, 1, 0, 0, GridBagConstraints.NORTHEAST, GridBagConstraints.NONE, new Insets(5, 5, 5, 5), 0, 0));
    calendarPropertiesLeftPanel.add(skinValue, new GridBagConstraints(1, count, 1, 1, 1, 0, GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 5, 5), 0, 0));
    count++;
    calendarPropertiesLeftPanel.add(maxWeekDaysNamesLengthText, new GridBagConstraints(0, count, 1, 1, 0, 0, GridBagConstraints.NORTHEAST, GridBagConstraints.NONE, new Insets(5, 5, 5, 5), 0, 0));
    calendarPropertiesLeftPanel.add(maxWeekDaysNamesLengthValue, new GridBagConstraints(1, count, 1, 1, 1, 0, GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 5, 5), 0, 0));
    count++;
    calendarPropertiesLeftPanel.add(maxMonthsNamesLengthText, new GridBagConstraints(0, count, 1, 1, 0, 0, GridBagConstraints.NORTHEAST, GridBagConstraints.NONE, new Insets(5, 5, 5, 5), 0, 0));
    calendarPropertiesLeftPanel.add(maxMonthsNamesLengthValue, new GridBagConstraints(1, count, 1, 1, 1, 0, GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 5, 5), 0, 0));
    count++;
    calendarPropertiesLeftPanel.add(localeText, new GridBagConstraints(0, count, 1, 1, 0, 0, GridBagConstraints.NORTHEAST, GridBagConstraints.NONE, new Insets(5, 5, 5, 5), 0, 0));
    calendarPropertiesLeftPanel.add(localeValue, new GridBagConstraints(1, count, 1, 1, 1, 0, GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 5, 5), 0, 0));
    count++;
    calendarPropertiesLeftPanel.add(calendarSelectionModelsText, new GridBagConstraints(0, count, 1, 1, 0, 0, GridBagConstraints.NORTHEAST, GridBagConstraints.NONE, new Insets(5, 5, 5, 5), 0, 0));
    calendarPropertiesLeftPanel.add(calendarSelectionModelsValue, new GridBagConstraints(1, count, 1, 1, 1, 0, GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 5, 5), 0, 0));
    count++;
    
    count = 0;
    calendarPropertiesRightPanel.setLayout(new GridBagLayout());
    count++;
    
    count = 0;
    calendarPropertiesPanel.setBorder(BorderFactory.createTitledBorder("Calendar Properties"));
    calendarPropertiesPanel.setLayout(new GridBagLayout());
    calendarPropertiesPanel.add(calendarPropertiesLeftPanel, new GridBagConstraints(0, count, 1, 1, 0, 0, GridBagConstraints.NORTHEAST, GridBagConstraints.NONE, new Insets(5, 5, 5, 5), 0, 0));
    calendarPropertiesPanel.add(calendarPropertiesRightPanel, new GridBagConstraints(1, count, 1, 1, 1, 0, GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 5, 5), 0, 0));
    count++;
    
    //ComboBox Additional Properties
    
    comboBoxCloseWhenDateSelectedValue = new JCheckBox();
    comboBoxCloseWhenDateSelectedValue.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
        calendarComboBox.setCalendarComboBoxProperty(CalendarComboBox.CLOSE_WHEN_DATE_SELECTED, new Boolean(comboBoxCloseWhenDateSelectedValue.isSelected()));
        customTableCalendarComboBox.setCalendarComboBoxProperty(CalendarComboBox.CLOSE_WHEN_DATE_SELECTED, new Boolean(comboBoxCloseWhenDateSelectedValue.isSelected()));
        calendarDemoController.getCalendarDemo().getFrame().pack();
      }
    });
    comboBoxCloseWhenDateSelectedValue.setSelected(true);
    calendarComboBox.setCalendarComboBoxProperty(CalendarComboBox.CLOSE_WHEN_DATE_SELECTED, new Boolean(comboBoxCloseWhenDateSelectedValue.isSelected()));
    customTableCalendarComboBox.setCalendarComboBoxProperty(CalendarComboBox.CLOSE_WHEN_DATE_SELECTED, new Boolean(comboBoxCloseWhenDateSelectedValue.isSelected()));
    
    comboBoxCloseWhenDateSelectedText = new JLabel("Close When Date Selected:");
    comboBoxCloseWhenDateSelectedText.setDisplayedMnemonic('W');
    comboBoxCloseWhenDateSelectedText.setLabelFor(comboBoxCloseWhenDateSelectedValue);
    
    
    count = 0;
    comboboxPropertiesPanel.setBorder(BorderFactory.createTitledBorder("Calendar ComboBox Additional Properties"));
    comboboxPropertiesPanel.setLayout(new GridBagLayout());
    comboboxPropertiesPanel.add(comboBoxCloseWhenDateSelectedText, new GridBagConstraints(0, count, 1, 1, 0, 0, GridBagConstraints.NORTHEAST, GridBagConstraints.NONE, new Insets(5, 5, 5, 5), 0, 0));
    comboboxPropertiesPanel.add(comboBoxCloseWhenDateSelectedValue, new GridBagConstraints(1, count, 1, 1, 1, 0, GridBagConstraints.NORTHWEST, GridBagConstraints.HORIZONTAL, new Insets(5, 5, 5, 5), 0, 0));
    count++;
    
    
    datePanel.setBorder(BorderFactory.createTitledBorder("Date"));
    datePanel.setLayout(new GridBagLayout());
    datePanel.add(calendarComponent.getComponent(), new GridBagConstraints(0, 0, 1, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(0, 5, 5, 5), 0, 0));
    
    chosenDatePanel.setBorder(BorderFactory.createTitledBorder("Calendar ComboBox"));
    chosenDatePanel.setLayout(new GridBagLayout());
    chosenDatePanel.add(chosenDateText, new GridBagConstraints(0, 0, 1, 1, 0, 0, GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 5, 5), 0, 0));
    chosenDatePanel.add(calendarComboBox.getComboBoxComponent(), new GridBagConstraints(1, 0, 1, 1, 0, 0, GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 5, 5), 0, 0));
    chosenDatePanel.add(new JPanel(), new GridBagConstraints(2, 0, 1, 1, 1, 0, GridBagConstraints.NORTHWEST, GridBagConstraints.HORIZONTAL, new Insets(5, 5, 5, 5), 0, 0));
    
    tablePanel.setBorder(BorderFactory.createTitledBorder("JTable Cell Editor Calendar"));
    tablePanel.setLayout(new GridBagLayout());
    tablePanel.add(customTable.getTableHeader(), new GridBagConstraints(0, 0, 1, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(0, 0, 0, 0), 0, 0));
    tablePanel.add(customTable, new GridBagConstraints(0, 1, 1, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(0, 0, 0, 0), 0, 0));
    
    leftPanel.setLayout(new GridBagLayout());
    leftPanel.add(datePanel, new GridBagConstraints(0, 0, 1, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(0, 5, 5, 5), 0, 0));
    leftPanel.add(chosenDatePanel, new GridBagConstraints(0, 1, 1, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.HORIZONTAL, new Insets(5, 5, 5, 5), 0, 0));
    leftPanel.add(tablePanel, new GridBagConstraints(0, 2, 1, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.HORIZONTAL, new Insets(5, 5, 5, 5), 0, 0));
    
    this.setLayout(new GridBagLayout());
    this.add(leftPanel, new GridBagConstraints(0, 0, 1, 2, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 5, 5), 0, 0));
    this.add(calendarPropertiesPanel, new GridBagConstraints(1, 0, 1, 1, 1.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.HORIZONTAL, new Insets(5, 5, 5, 5), 0, 0));
    this.add(comboboxPropertiesPanel, new GridBagConstraints(1, 1, 1, 1, 1.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.HORIZONTAL, new Insets(5, 5, 5, 5), 0, 0));
    this.add(eventsPanel, new GridBagConstraints(0, 2, 2, 1, 1.0, 1.0, GridBagConstraints.NORTHWEST, GridBagConstraints.BOTH, new Insets(5, 5, 5, 5), 0, 0));
    
    CalendarComponentListener calendarComponentListener = new CalendarComponentListener() {
      
      public Class[] getEventsListened() {
        return new Class[] {
            CalendarEventFirstDayOfWeekChanged.class,
            CalendarEventGridVisibleStatusChanged.class,
            CalendarEventLocaleChanged.class,
            CalendarEventMaxMonthsNamesLengthChanged.class,
            CalendarEventMaxWeekDaysNamesLengthChanged.class,
            CalendarEventExtraMonthDaysVisibleStatusChanged.class,
            CalendarEventCalendarRendererProviderChanged.class,
            CalendarEventSkinPropertyChanged.class,
            CalendarEventSkinStyleChanged.class,
            CalendarEventHoverEffectStatusChanged.class,
            CalendarEventStatusPanelVisibleValueChanged.class,
            CalendarEventWeekVisibleStatusChanged.class,
            CalendarEventSelectionModelChanged.class,
        };
      }
      
      public void processCalendarEvent(CalendarEvent calendarEvent) {
        if (calendarEvent instanceof CalendarEventFirstDayOfWeekChanged) {
          int firstDayOfWeek = ((CalendarEventFirstDayOfWeekChanged)calendarEvent).getFirstDayOfWeek();
          String message = "First day of week changed to:";
          switch(firstDayOfWeek) {
            case Calendar.SUNDAY: 
              message += "SUNDAY";
              break;
            case Calendar.MONDAY: 
              message += "MONDAY";
              break;
            case Calendar.TUESDAY: 
              message += "TUESDAY";
              break;
            case Calendar.WEDNESDAY: 
              message += "WEDNESDAY";
              break;
            case Calendar.THURSDAY: 
              message += "THURSDAY";
              break;
            case Calendar.FRIDAY: 
              message += "FRIDAY";
              break;
            case Calendar.SATURDAY: 
              message += "SATURDAY";
              break;
          };
          if (eventsTextArea.getText().length() > 0) {
            eventsTextArea.append("\n");
          }
          eventsTextArea.append(message);
        } else if (calendarEvent instanceof CalendarEventGridVisibleStatusChanged) {
          boolean showGrid = ((CalendarEventGridVisibleStatusChanged)calendarEvent).getShowGrid();
          String message = "Now the calendar grid is:";
          if (showGrid) {
            message += "visible";
          } else {
            message += "not visible";
          }
          if (eventsTextArea.getText().length() > 0) {
            eventsTextArea.append("\n");
          }
          eventsTextArea.append(message);
        } else if (calendarEvent instanceof CalendarEventExtraMonthDaysVisibleStatusChanged) {
          boolean extraMonthDaysVisible = ((CalendarEventExtraMonthDaysVisibleStatusChanged)calendarEvent).getExtraMonthDaysVisible();
          String message = "Now the extra month days are:";
          if (extraMonthDaysVisible) {
            message += "visible";
          } else {
            message += "not visible";
          }
          if (eventsTextArea.getText().length() > 0) {
            eventsTextArea.append("\n");
          }
          eventsTextArea.append(message);
        } else if (calendarEvent instanceof CalendarEventLocaleChanged) {
          Locale locale = ((CalendarEventLocaleChanged)calendarEvent).getLocale();
          String message = "Now the calendar locale is:" + locale.getDisplayName();
          if (eventsTextArea.getText().length() > 0) {
            eventsTextArea.append("\n");
          }
          eventsTextArea.append(message);
        } else if (calendarEvent instanceof CalendarEventMaxMonthsNamesLengthChanged) {
          int maxMonthsNamesLength = ((CalendarEventMaxMonthsNamesLengthChanged)calendarEvent).getMaxMonthsNamesLength();
          String message = "Now the maximum months names length is:" + maxMonthsNamesLength;
          if (eventsTextArea.getText().length() > 0) {
            eventsTextArea.append("\n");
          }
          eventsTextArea.append(message);
        } else if (calendarEvent instanceof CalendarEventMaxWeekDaysNamesLengthChanged) {
          int maxWeekDaysNamesLength = ((CalendarEventMaxWeekDaysNamesLengthChanged)calendarEvent).getMaxWeekDaysNamesLength();
          String message = "Now the maximum week days names length is:" + maxWeekDaysNamesLength;
          if (eventsTextArea.getText().length() > 0) {
            eventsTextArea.append("\n");
          }
          eventsTextArea.append(message);
        } else if (calendarEvent instanceof CalendarEventSkinPropertyChanged) {
          String propertyName = ((CalendarEventSkinPropertyChanged)calendarEvent).getCalendarProperty().getName();
          Object propertyValue = ((CalendarEventSkinPropertyChanged)calendarEvent).getPropertyValue();
          String message = "The \"" + propertyName + "\" property has changed to the value: " + propertyValue.toString();
          if (eventsTextArea.getText().length() > 0) {
            eventsTextArea.append("\n");
          }
          eventsTextArea.append(message);
        } else if (calendarEvent instanceof CalendarEventSkinStyleChanged) {
          String calendarSkinStyleName = ((CalendarEventSkinStyleChanged)calendarEvent).getCalendarSkinStyle().getName();
          String message = "The calendar skin style has changed into:" + calendarSkinStyleName;
          if (eventsTextArea.getText().length() > 0) {
            eventsTextArea.append("\n");
          }
          eventsTextArea.append(message);
        } else if (calendarEvent instanceof CalendarEventCalendarRendererProviderChanged) {
          String text = ((CalendarEventCalendarRendererProviderChanged)calendarEvent).getCalendarRendererProvider().getName();
          String message = "The calendar renderer provider has changed into:" + text;
          if (eventsTextArea.getText().length() > 0) {
            eventsTextArea.append("\n");
          }
          eventsTextArea.append(message);
        } else if (calendarEvent instanceof CalendarEventHoverEffectStatusChanged) {
          boolean showHover = ((CalendarEventHoverEffectStatusChanged)calendarEvent).getHoverEffectStatus();
          String message = "Now the hover effect is:";
          if (showHover) {
            message += "enabled";
          } else {
            message += "disabled";
          }
          if (eventsTextArea.getText().length() > 0) {
            eventsTextArea.append("\n");
          }
          eventsTextArea.append(message);
        } else if (calendarEvent instanceof CalendarEventStatusPanelVisibleValueChanged) {
            boolean statusPanelVisible = ((CalendarEventStatusPanelVisibleValueChanged)calendarEvent).getStatusPanelVisible();
            String message = "Now the status panel is:";
            if (statusPanelVisible) {
              message += "visible";
            } else {
              message += "not visible";
            }
            if (eventsTextArea.getText().length() > 0) {
              eventsTextArea.append("\n");
            }
            eventsTextArea.append(message);
        } else if (calendarEvent instanceof CalendarEventWeekVisibleStatusChanged) {
          boolean showWeek = ((CalendarEventWeekVisibleStatusChanged)calendarEvent).getWeekVisibleStatus();
          String message = "Now the week is:";
          if (showWeek) {
            message += "visible";
          } else {
            message += "not visible";
          }
          if (eventsTextArea.getText().length() > 0) {
            eventsTextArea.append("\n");
          }
          eventsTextArea.append(message);
        } else if (calendarEvent instanceof CalendarEventSelectionModelChanged) {
        	CalendarSelectionModel calendarSelectionModel = ((CalendarEventSelectionModelChanged)calendarEvent).getCalendarSelectionModel();
            String message = "The calendar selection model was changed to:" + calendarSelectionModel.getName();
            if (eventsTextArea.getText().length() > 0) {
              eventsTextArea.append("\n");
            }
            eventsTextArea.append(message);
        }
      }
    };
    calendarComponent.addCalendarComponentListener(calendarComponentListener);
    
    DateListener dateListener = new DateListener() {
      public void dateChanged(Date date) {
    	  if (eventsTextArea.getText().length() > 0) {
    		  eventsTextArea.append("\n");
    	  }
          if (date == null) {
        	  eventsTextArea.append("Date changed to: null");
        	  calendarDemoController.getCalendarDemo().getFrame().pack();
        	  return;
          }
          GregorianCalendar calendar = new GregorianCalendar();
          calendar.setTime(date);
          eventsTextArea.append("Date changed to:" + calendar.get(Calendar.YEAR) + "." + (calendar.get(Calendar.MONTH) + 1) + "." + calendar.get(Calendar.DAY_OF_MONTH));
          calendarDemoController.getCalendarDemo().getFrame().pack();
      }
    };
    calendarComponent.addDateListener(dateListener);
    
  }
  
  private String dateToString(Date tempDate) {
    String result;
    GregorianCalendar gregorianCalendar = new GregorianCalendar();
    gregorianCalendar.setTime(tempDate);
    int year = gregorianCalendar.get(Calendar.YEAR);
    int month = gregorianCalendar.get(Calendar.MONTH);
    int day = gregorianCalendar.get(Calendar.DAY_OF_MONTH);
    result = day + "  " + monthsNames[month] + "  " + year + "  ";
    return result;
  }
  
  private boolean updateEmptySelectionAllowed(CalendarComponent calendarComponent, String text) {
      try {
			calendarComponent.getCalendarSelectionModel().setEmptySelectionAllowed(emptySelectionAllowedValue.isSelected());
			return true;
		} catch (EmptySelectionNotAllowedException ex) {
	          if (eventsTextArea.getText().length() > 0) {
	              eventsTextArea.append("\n");
	            }
	            eventsTextArea.append(text + ":" + ex.getMessage());
	            emptySelectionAllowedValue.setSelected(emptySelectionAllowedValue.isSelected());
	            return false;
		}
  }
  
  private void updateSelectionModel(CalendarComponent calendarComponent, CalendarSelectionModel templateCalendarSelectionModel) {
	  try {
		Date[] dates = calendarComponent.getCalendarSelectionModel().getSelectedDates();
		calendarComponent.setCalendarSelectionModel((CalendarSelectionModel) templateCalendarSelectionModel.getClass().newInstance());
		calendarComponent.getCalendarSelectionModel().setSelectedDates(dates);
		calendarComponent.getCalendarSelectionModel().setEmptySelectionAllowed(emptySelectionAllowedValue.isSelected());
	} catch (Exception e) {
	}
  }
  
  private void updateRendererProvider(CalendarComponent calendarComponent, CalendarRendererProvider templateCalendarRendererProvider) {
	  try {
		calendarComponent.setCalendarRendererProvider((CalendarRendererProvider) templateCalendarRendererProvider.getClass().newInstance());
	} catch (Exception e) {
	}
  }
  
  public String getTitle() {
    return "Main Features";
  }
  
}
