package com.imagine.component.calendar.demo.panels.skineditor;

import java.awt.*;
import java.awt.event.*;
import java.io.*;
import java.net.*;
import java.util.*;

import javax.swing.*;
import javax.xml.parsers.*;

import org.xml.sax.SAXException;

import com.imagine.component.calendar.*;
import com.imagine.component.calendar.demo.CalendarDemoController;
import com.imagine.component.calendar.demo.panels.CalendarDemoPanel;
import com.imagine.component.calendar.events.*;
import com.imagine.component.calendar.selection.CalendarSelectionModelMultipleIntervalSelection;
import com.imagine.component.calendar.skins.CalendarSkin;
import com.imagine.component.calendar.skins.external.*;

public class CalendarDemoPanelSkinEditor extends CalendarDemoPanel {

  private CalendarComponent calendarComponent = null;
  
  JLabel skinNameLabel;
  JTextField skinNameTextField;
  
  ColorComponent cellTextColorComponent;
  ColorComponent cellFillColorComponent;
  ColorComponent todayColorComponent;
  ColorComponent disabledColorComponent;
  ColorComponent selectedCellTextColorComponent;
  ColorComponent selectedCellFillColorComponent;
  ColorComponent hoveredCellTextColorComponent;
  ColorComponent hoveredCellFillColorComponent;
  ColorComponent weekendCellTextColorComponent;
  ColorComponent extraMonthCellTextColorComponent;
  ColorComponent gridColorComponent;
  ColorComponent headerTextColorComponent;
  ColorComponent headerFillColorComponent;
  ColorComponent weekTextColorComponent;
  ColorComponent weekFillColorComponent;
  ColorComponent statusPanelTextColorComponent;
  ColorComponent statusPanelHoveredTextColorComponent;
  ColorComponent statusPanelFillColorComponent;
  
  FontComponent cellFontComponent;
  FontComponent weekendCellFontComponent;
  FontComponent extraMonthCellFontComponent;
  FontComponent headerFontComponent;
  FontComponent weekFontComponent;
  FontComponent statusPanelFontComponent;
  
  public CalendarDemoPanelSkinEditor(CalendarDemoController calendarDemoController) {
    super(calendarDemoController);
    
    initialize();
  }
  
  public void initialize() {
    JPanel panel = new JPanel();
    JPanel leftPanel = new JPanel();
    JPanel datePanel = new JPanel();
    JPanel fileSkinsPanel = new JPanel();
    JPanel urlSkinsPanel = new JPanel();
    JPanel rightPanel = new JPanel();
    JPanel skinNamePanel = new JPanel();
    JPanel colorsPanel = new JPanel();
    JPanel fontsPanel = new JPanel();
    
    JTabbedPane tabbedPane = new JTabbedPane();
    
    JButton loadFromFileButton = new JButton("Load Skin From File");
    JButton saveToFileButton = new JButton("Save Skin To File");
    
    CalendarFactory calendarFactory = CalendarFactory.getInstance();
    calendarComponent = calendarFactory.createCalendarComponent(new Date());
    calendarComponent.setCalendarProperty(CalendarComponent.SHOW_GRID, new Boolean(true));
    calendarComponent.setCalendarProperty(CalendarComponent.SHOW_WEEK, new Boolean(true));
    calendarComponent.setCalendarProperty(CalendarComponent.SHOW_HOVER, new Boolean(true));
    calendarComponent.setCalendarProperty(CalendarComponent.SHOW_EXTRA_MONTH_DAYS, new Boolean(true));
    calendarComponent.setCalendarProperty(CalendarComponent.SHOW_STATUS_PANEL, new Boolean(true));
    calendarComponent.setCalendarProperty(CalendarComponent.FIRST_DAY_OF_WEEK, new Integer(Calendar.MONDAY));
    calendarComponent.setCalendarProperty(CalendarComponent.MAX_WEEK_DAYS_NAMES_LENGTH, new Integer(3));
    
    calendarComponent.setCalendarSelectionModel(new CalendarSelectionModelMultipleIntervalSelection() {
    	  private GregorianCalendar calendar = new GregorianCalendar();
    	  
    	  public boolean isDateDisabled(Date date) {
    	    calendar.setTime(date);
    	    return (calendar.get(Calendar.DAY_OF_MONTH) == 15);
    	  }
	});
    calendarComponent.getCalendarSelectionModel().setEmptySelectionAllowed(true);
    
    calendarComponent.addCalendarComponentListener(new CalendarComponentListener() {
      public void processCalendarEvent(CalendarEvent calendarEvent) {
        if (calendarEvent instanceof CalendarEventSkinPropertyChanged) {
          CalendarEventSkinPropertyChanged calendarEventSkinPropertyChanged = (CalendarEventSkinPropertyChanged)calendarEvent;
          if (calendarEventSkinPropertyChanged.getCalendarProperty().getType().equals(Font.class)) {
            CalendarDemoPanelSkinEditor.this.getCalendarDemoController().getCalendarDemo().getFrame().pack();
          }
        }
      }

      public Class[] getEventsListened() {
        return new Class[] {
            CalendarEventSkinPropertyChanged.class,
        };
      }
    });
    
    
    this.setLayout(new GridBagLayout());
    this.add(leftPanel, new GridBagConstraints(0, 0, 1, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(15, 5, 5, 5), 0, 0));
    this.add(rightPanel, new GridBagConstraints(1, 0, 1, 1, 1.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(25, 5, 5, 5), 0, 0));
    this.add(new JPanel(), new GridBagConstraints(2, 0, 2, 1, 1.0, 1.0, GridBagConstraints.NORTHWEST, GridBagConstraints.BOTH, new Insets(0, 0, 0, 0), 0, 0));
    
    leftPanel.setLayout(new GridBagLayout());
    leftPanel.add(datePanel, new GridBagConstraints(0, 0, 1, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 5, 5), 0, 0));
    leftPanel.add(fileSkinsPanel, new GridBagConstraints(0, 1, 1, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 5, 5), 0, 0));
    leftPanel.add(urlSkinsPanel, new GridBagConstraints(0, 2, 1, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 5, 5), 0, 0));
    
    fileSkinsPanel.setBorder(BorderFactory.createTitledBorder("File"));
    fileSkinsPanel.setLayout(new GridBagLayout());
    fileSkinsPanel.add(loadFromFileButton, new GridBagConstraints(0, 0, 1, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.HORIZONTAL, new Insets(5, 5, 5, 5), 0, 0));
    fileSkinsPanel.add(saveToFileButton, new GridBagConstraints(0, 1, 1, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.HORIZONTAL, new Insets(5, 5, 5, 5), 0, 0));
    
    loadFromFileButton.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent event) {
        try {
          JFileChooser fileChooser = new JFileChooser("./skins");
          if (fileChooser.showOpenDialog(calendarDemoController.getCalendarDemo().getFrame()) == JFileChooser.APPROVE_OPTION) {
            File file = fileChooser.getSelectedFile();
            try {
              CalendarSkinStyleExternalFile calendarSkinStyle = new CalendarSkinStyleExternalFile(file);
              calendarComponent.getCalendarSkin().applyCalendarSkinStyle(calendarSkinStyle);

              updateInterface();
            } catch (Exception ex) {
            }
          }
        } catch (Exception exception) {
         JOptionPane.showMessageDialog(CalendarDemoPanelSkinEditor.this, 
             "<html>This function is not available when this demo is run through JNLP for security reasons. <br>" + 
             " If you want to view this feature please download the demo from the download section <br>" +
             " of the site and run the demo locally on your machine. " +
             "</html>"
         ); 
        }
      }
    }
    );
    
    saveToFileButton.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent event) {
        try {
          JFileChooser fileChooser = new JFileChooser("./skins");
          if (fileChooser.showSaveDialog(calendarDemoController.getCalendarDemo().getFrame()) == JFileChooser.APPROVE_OPTION) {
            File file = fileChooser.getSelectedFile();
            try {
              calendarComponent.getCalendarSkin().setName(skinNameTextField.getText());
              CalendarSkinStyleExternalFile.exportSkin(calendarComponent.getCalendarSkin(), file);
            } catch (Exception ex) {
            }
          }
        } catch (Exception e) {
          JOptionPane.showMessageDialog(CalendarDemoPanelSkinEditor.this, 
              "<html>This function is not available when this demo is run through JNLP for security reasons. <br>" + 
              " If you want to view this feature please download the demo from the download section <br>" +
              " of the site and run the demo locally on your machine. " +
              "</html>"
          ); 
        }
      }
    }
    );
    
    
    datePanel.setLayout(new GridBagLayout());
    datePanel.add(calendarComponent.getComponent(), new GridBagConstraints(0, 0, 1, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 5, 5), 0, 0));
    datePanel.setBorder(BorderFactory.createTitledBorder("Date"));
    
    String[] urls = new String[] {
      " ",  
      "http://www.java-calendar.com/skins/skin01.skin",  
      "http://www.java-calendar.com/skins/skin02.skin",  
      "http://www.java-calendar.com/skins/skin03.skin",  
//      "http://www.java-calendar.com/skins/skin04.skin"  
    };
    try {
        Vector urlsVector = new Vector();
        urlsVector.add(" ");
    	URLConnection connection = new URL("http://www.java-calendar.com/skins/skins.php").openConnection();
    	BufferedReader reader = new BufferedReader(new InputStreamReader(connection.getInputStream()));
    	String line = null;
    	while ((line = reader.readLine()) != null) {
    		urlsVector.add(line.trim());
    	}
    	((HttpURLConnection)connection).disconnect();
    	urls = (String[])urlsVector.toArray(new String[urlsVector.size()]); 
    } catch (Exception ex) {
    }
    JComboBox urlComboBox = new JComboBox(urls);
    urlComboBox.setEditable(true);
    urlComboBox.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
        JComboBox comboBox = (JComboBox)e.getSource();
        String urlText = (String)comboBox.getSelectedItem();
        try {
          URL url = new URL(urlText);
          calendarComponent.getCalendarSkin().applyCalendarSkinStyle(new CalendarSkinStyleExternalURL(url));
          updateInterface();          
        } catch (MalformedURLException ex) {
          JOptionPane.showMessageDialog(CalendarDemoPanelSkinEditor.this, "Invalid URL entered: " + ex.getMessage()); 
        } catch (FileNotFoundException ex2) {
          JOptionPane.showMessageDialog(CalendarDemoPanelSkinEditor.this, "The skin specified was not found: " + ex2.getMessage()); 
        } catch (SAXException ex3) {
          JOptionPane.showMessageDialog(CalendarDemoPanelSkinEditor.this, "Invalid skin: " + ex3.getMessage()); 
        } catch (IOException ex4) {
          JOptionPane.showMessageDialog(CalendarDemoPanelSkinEditor.this, "The skin specified was not found: " + ex4.getMessage()); 
        } catch (ParserConfigurationException ex5) {
          JOptionPane.showMessageDialog(CalendarDemoPanelSkinEditor.this, "Invalid skin: " + ex5.getMessage()); 
        } catch (FactoryConfigurationError ex6) {
          JOptionPane.showMessageDialog(CalendarDemoPanelSkinEditor.this, "Invalid skin: " + ex6.getMessage()); 
        } catch (NullPointerException ex7) {
          JOptionPane.showMessageDialog(CalendarDemoPanelSkinEditor.this, "Invalid URL entered: " + ex7.getMessage()); 
        }
      }
    });
    
    urlSkinsPanel.setBorder(BorderFactory.createTitledBorder("URL"));
    urlSkinsPanel.setLayout(new GridBagLayout());
    urlSkinsPanel.add(urlComboBox, new GridBagConstraints(0, 0, 1, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.HORIZONTAL, new Insets(5, 5, 5, 5), 0, 0));
    
    rightPanel.setLayout(new GridBagLayout());
    rightPanel.add(skinNamePanel, new GridBagConstraints(0, 0, 1, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.BOTH, new Insets(0, 0, 0, 0), 0, 0));
    rightPanel.add(tabbedPane, new GridBagConstraints(0, 1, 1, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.BOTH, new Insets(0, 0, 0, 0), 0, 0));
    tabbedPane.add(colorsPanel, "Colors");
    tabbedPane.add(fontsPanel, "Fonts");
    
    skinNameLabel = new JLabel("Skin Name:");
    skinNameTextField = new JTextField(10);
    skinNamePanel.setBorder(BorderFactory.createTitledBorder("Skin Name"));
    skinNamePanel.setLayout(new GridBagLayout());
    skinNamePanel.add(skinNameLabel, new GridBagConstraints(0, 0, 1, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.BOTH, new Insets(0, 0, 0, 0), 0, 0));
    skinNamePanel.add(skinNameTextField, new GridBagConstraints(1, 0, 1, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.BOTH, new Insets(0, 0, 0, 0), 0, 0));
    skinNameTextField.setText(calendarComponent.getCalendarSkin().getName());
    
    cellTextColorComponent = new ColorComponent() {
      public void updateValue() {
        calendarComponent.getCalendarSkin().setSkinProperty(CalendarSkin.CELL_TEXT_COLOR, getColor());
      }
    };
    cellTextColorComponent.setLabel("Cell Text Color:");
    
    cellFillColorComponent = new ColorComponent() {
      public void updateValue() {
        calendarComponent.getCalendarSkin().setSkinProperty(CalendarSkin.CELL_FILL_COLOR, getColor());
      }
    };
    cellFillColorComponent.setLabel("Cell Fill Color:");
    
    todayColorComponent = new ColorComponent() {
      public void updateValue()  {
        calendarComponent.getCalendarSkin().setSkinProperty(CalendarSkin.TODAY_COLOR, getColor());
      }
    };
    todayColorComponent.setLabel("Today Color:");
    
    disabledColorComponent = new ColorComponent() {
        public void updateValue()  {
          calendarComponent.getCalendarSkin().setSkinProperty(CalendarSkin.DISABLED_COLOR, getColor());
        }
      };
      disabledColorComponent.setLabel("Disabled Color:");
      
    selectedCellTextColorComponent = new ColorComponent() {
      public void updateValue()  {
        calendarComponent.getCalendarSkin().setSkinProperty(CalendarSkin.SELECTED_CELL_TEXT_COLOR, getColor());
      }
    };
    selectedCellTextColorComponent.setLabel("Selected Cell Text Color:");
    
    selectedCellFillColorComponent = new ColorComponent() {
      public void updateValue()  {
        calendarComponent.getCalendarSkin().setSkinProperty(CalendarSkin.SELECTED_CELL_FILL_COLOR, getColor());
      }
    };
    selectedCellFillColorComponent.setLabel("Selected Cell Fill Color:");
    
    hoveredCellTextColorComponent = new ColorComponent() {
      public void updateValue()  {
        calendarComponent.getCalendarSkin().setSkinProperty(CalendarSkin.HOVERED_CELL_TEXT_COLOR, getColor());
      }
    };
    hoveredCellTextColorComponent.setLabel("Hovered Cell Text Color:");
    
    hoveredCellFillColorComponent = new ColorComponent() {
      public void updateValue()  {
        calendarComponent.getCalendarSkin().setSkinProperty(CalendarSkin.HOVERED_CELL_FILL_COLOR, getColor());
      }
    };
    hoveredCellFillColorComponent.setLabel("Hovered Cell Fill Color:");
    
    weekendCellTextColorComponent = new ColorComponent() {
      public void updateValue()  {
        calendarComponent.getCalendarSkin().setSkinProperty(CalendarSkin.WEEKEND_CELL_TEXT_COLOR, getColor());
      }
    };
    weekendCellTextColorComponent.setLabel("Weekend Cell Text Color:");
    
    extraMonthCellTextColorComponent = new ColorComponent() {
      public void updateValue()  {
        calendarComponent.getCalendarSkin().setSkinProperty(CalendarSkin.EXTRA_MONTH_CELL_TEXT_COLOR, getColor());
      }
    };
    extraMonthCellTextColorComponent.setLabel("Extra Month Cell Text Color:");
    
    gridColorComponent = new ColorComponent() {
      public void updateValue()  {
        calendarComponent.getCalendarSkin().setSkinProperty(CalendarSkin.GRID_COLOR, getColor());
      }
    };
    gridColorComponent.setLabel("Grid Color:");
    
    headerTextColorComponent = new ColorComponent() {
      public void updateValue()  {
        calendarComponent.getCalendarSkin().setSkinProperty(CalendarSkin.HEADER_CELL_TEXT_COLOR, getColor());
      }
    };
    headerTextColorComponent.setLabel("Header Text Color:");
    
    headerFillColorComponent = new ColorComponent() {
      public void updateValue()  {
        calendarComponent.getCalendarSkin().setSkinProperty(CalendarSkin.HEADER_CELL_FILL_COLOR, getColor());
      }
    };
    headerFillColorComponent.setLabel("Header Fill Color:");
    
    weekTextColorComponent = new ColorComponent() {
      public void updateValue()  {
        calendarComponent.getCalendarSkin().setSkinProperty(CalendarSkin.WEEK_CELL_TEXT_COLOR, getColor());
      }
    };
    weekTextColorComponent.setLabel("Week Text Color:");
    
    weekFillColorComponent = new ColorComponent() {
      public void updateValue()  {
        calendarComponent.getCalendarSkin().setSkinProperty(CalendarSkin.WEEK_CELL_FILL_COLOR, getColor());
      }
    };
    weekFillColorComponent.setLabel("Week Fill Color:");
    
    statusPanelTextColorComponent = new ColorComponent() {
        public void updateValue()  {
          calendarComponent.getCalendarSkin().setSkinProperty(CalendarSkin.STATUS_PANEL_TEXT_COLOR, getColor());
        }
      };
      statusPanelTextColorComponent.setLabel("Status Panel Text Color:");
      
      statusPanelHoveredTextColorComponent = new ColorComponent() {
          public void updateValue()  {
            calendarComponent.getCalendarSkin().setSkinProperty(CalendarSkin.STATUS_PANEL_HOVERED_TEXT_COLOR, getColor());
          }
        };
        statusPanelHoveredTextColorComponent.setLabel("Status Panel Hovered Text Color:");
        
      statusPanelFillColorComponent = new ColorComponent() {
        public void updateValue()  {
          calendarComponent.getCalendarSkin().setSkinProperty(CalendarSkin.STATUS_PANEL_FILL_COLOR, getColor());
        }
      };
      statusPanelFillColorComponent.setLabel("Status Panel Fill Color:");
      
    cellFontComponent = new FontComponent() {
      public void updateValue()  {
        calendarComponent.getCalendarSkin().setSkinProperty(CalendarSkin.CELL_FONT, getFont());
      }
    };
    cellFontComponent.setLabel("Cell Font:");
    
    weekendCellFontComponent = new FontComponent() {
      public void updateValue()  {
        calendarComponent.getCalendarSkin().setSkinProperty(CalendarSkin.WEEKEND_CELL_FONT, getFont());
      }
    };
    weekendCellFontComponent.setLabel("Weekend Cell Font:");
    
    extraMonthCellFontComponent = new FontComponent() {
      public void updateValue()  {
        calendarComponent.getCalendarSkin().setSkinProperty(CalendarSkin.EXTRA_MONTH_CELL_FONT, getFont());
      }
    };
    extraMonthCellFontComponent.setLabel("Extra Month Cell Font:");
    
    headerFontComponent = new FontComponent() {
      public void updateValue()  {
        calendarComponent.getCalendarSkin().setSkinProperty(CalendarSkin.HEADER_CELL_FONT, getFont());
      }
    };
    headerFontComponent.setLabel("Header Font:");
    
    weekFontComponent = new FontComponent() {
      public void updateValue()  {
        calendarComponent.getCalendarSkin().setSkinProperty(CalendarSkin.WEEK_CELL_FONT, getFont());
      }
    };
    weekFontComponent.setLabel("Week Font:");
    
    statusPanelFontComponent = new FontComponent() {
        public void updateValue()  {
          calendarComponent.getCalendarSkin().setSkinProperty(CalendarSkin.STATUS_PANEL_FONT, getFont());
        }
      };
      statusPanelFontComponent.setLabel("Status Panel Font:");
    
    
    
    updateInterface();
    
    int count = 0;
//    colorsPanel.setBorder(BorderFactory.createTitledBorder("Colors"));
    colorsPanel.setLayout(new GridBagLayout());
    colorsPanel.add(cellTextColorComponent, new GridBagConstraints(0, count, 1, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.BOTH, new Insets(0, 0, 0, 0), 0, 0));
    count++;
    colorsPanel.add(cellFillColorComponent, new GridBagConstraints(0, count, 1, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.BOTH, new Insets(0, 0, 0, 0), 0, 0));
    count++;
    colorsPanel.add(todayColorComponent, new GridBagConstraints(0, count, 1, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.BOTH, new Insets(0, 0, 0, 0), 0, 0));
    count++;
    colorsPanel.add(disabledColorComponent, new GridBagConstraints(0, count, 1, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.BOTH, new Insets(0, 0, 0, 0), 0, 0));
    count++;
    colorsPanel.add(selectedCellTextColorComponent, new GridBagConstraints(0, count, 1, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.BOTH, new Insets(0, 0, 0, 0), 0, 0));
    count++;
    colorsPanel.add(selectedCellFillColorComponent, new GridBagConstraints(0, count, 1, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.BOTH, new Insets(0, 0, 0, 0), 0, 0));
    count++;
    colorsPanel.add(hoveredCellTextColorComponent, new GridBagConstraints(0, count, 1, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.BOTH, new Insets(0, 0, 0, 0), 0, 0));
    count++;
    colorsPanel.add(hoveredCellFillColorComponent, new GridBagConstraints(0, count, 1, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.BOTH, new Insets(0, 0, 0, 0), 0, 0));
    count++;
    colorsPanel.add(weekendCellTextColorComponent, new GridBagConstraints(0, count, 1, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.BOTH, new Insets(0, 0, 0, 0), 0, 0));
    count++;
    colorsPanel.add(extraMonthCellTextColorComponent, new GridBagConstraints(0, count, 1, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.BOTH, new Insets(0, 0, 0, 0), 0, 0));
    count++;
    colorsPanel.add(gridColorComponent, new GridBagConstraints(0, count, 1, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.BOTH, new Insets(0, 0, 0, 0), 0, 0));
    count++;
    colorsPanel.add(headerTextColorComponent, new GridBagConstraints(0, count, 1, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.BOTH, new Insets(0, 0, 0, 0), 0, 0));
    count++;
    colorsPanel.add(headerFillColorComponent, new GridBagConstraints(0, count, 1, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.BOTH, new Insets(0, 0, 0, 0), 0, 0));
    count++;
    colorsPanel.add(weekTextColorComponent, new GridBagConstraints(0, count, 1, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.BOTH, new Insets(0, 0, 0, 0), 0, 0));
    count++;
    colorsPanel.add(weekFillColorComponent, new GridBagConstraints(0, count, 1, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.BOTH, new Insets(0, 0, 0, 0), 0, 0));
    count++;
    colorsPanel.add(statusPanelTextColorComponent, new GridBagConstraints(0, count, 1, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.BOTH, new Insets(0, 0, 0, 0), 0, 0));
    count++;
    colorsPanel.add(statusPanelHoveredTextColorComponent, new GridBagConstraints(0, count, 1, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.BOTH, new Insets(0, 0, 0, 0), 0, 0));
    count++;
    colorsPanel.add(statusPanelFillColorComponent, new GridBagConstraints(0, count, 1, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.BOTH, new Insets(0, 0, 0, 0), 0, 0));
    count++;
    colorsPanel.add(new JPanel(), new GridBagConstraints(0, count, 1, 1, 0.0, 1.0, GridBagConstraints.NORTHWEST, GridBagConstraints.BOTH, new Insets(0, 0, 0, 0), 0, 0));
    count++;
    
    count = 0;
//    fontsPanel.setBorder(BorderFactory.createTitledBorder("Fonts"));
    fontsPanel.setLayout(new GridBagLayout());
    fontsPanel.add(cellFontComponent, new GridBagConstraints(0, count, 1, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.BOTH, new Insets(0, 0, 0, 0), 0, 0));
    count++;    
    fontsPanel.add(weekendCellFontComponent, new GridBagConstraints(0, count, 1, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.BOTH, new Insets(0, 0, 0, 0), 0, 0));
    count++;    
    fontsPanel.add(extraMonthCellFontComponent, new GridBagConstraints(0, count, 1, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.BOTH, new Insets(0, 0, 0, 0), 0, 0));
    count++;    
    fontsPanel.add(headerFontComponent, new GridBagConstraints(0, count, 1, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.BOTH, new Insets(0, 0, 0, 0), 0, 0));
    count++;    
    fontsPanel.add(weekFontComponent, new GridBagConstraints(0, count, 1, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.BOTH, new Insets(0, 0, 0, 0), 0, 0));
    count++;    
    fontsPanel.add(statusPanelFontComponent, new GridBagConstraints(0, count, 1, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.BOTH, new Insets(0, 0, 0, 0), 0, 0));
    count++;    
    fontsPanel.add(new JPanel(), new GridBagConstraints(0, count, 1, 1, 0.0, 1.0, GridBagConstraints.NORTHWEST, GridBagConstraints.BOTH, new Insets(0, 0, 0, 0), 0, 0));
    count++;    
  }
  
  private void updateInterface() {
    skinNameTextField.setText(calendarComponent.getCalendarSkin().getName());
    cellTextColorComponent.setColor(calendarComponent.getCalendarSkin().getColorSkinProperty(CalendarSkin.CELL_TEXT_COLOR));
    cellFillColorComponent.setColor(calendarComponent.getCalendarSkin().getColorSkinProperty(CalendarSkin.CELL_FILL_COLOR));
    todayColorComponent.setColor(calendarComponent.getCalendarSkin().getColorSkinProperty(CalendarSkin.TODAY_COLOR));
    disabledColorComponent.setColor(calendarComponent.getCalendarSkin().getColorSkinProperty(CalendarSkin.DISABLED_COLOR));
    selectedCellTextColorComponent.setColor(calendarComponent.getCalendarSkin().getColorSkinProperty(CalendarSkin.SELECTED_CELL_TEXT_COLOR));
    selectedCellFillColorComponent.setColor(calendarComponent.getCalendarSkin().getColorSkinProperty(CalendarSkin.SELECTED_CELL_FILL_COLOR));
    weekendCellTextColorComponent.setColor(calendarComponent.getCalendarSkin().getColorSkinProperty(CalendarSkin.WEEKEND_CELL_TEXT_COLOR));
    extraMonthCellTextColorComponent.setColor(calendarComponent.getCalendarSkin().getColorSkinProperty(CalendarSkin.EXTRA_MONTH_CELL_TEXT_COLOR));
    gridColorComponent.setColor(calendarComponent.getCalendarSkin().getColorSkinProperty(CalendarSkin.GRID_COLOR));
    headerTextColorComponent.setColor(calendarComponent.getCalendarSkin().getColorSkinProperty(CalendarSkin.HEADER_CELL_TEXT_COLOR));
    headerFillColorComponent.setColor(calendarComponent.getCalendarSkin().getColorSkinProperty(CalendarSkin.HEADER_CELL_FILL_COLOR));
    hoveredCellTextColorComponent.setColor(calendarComponent.getCalendarSkin().getColorSkinProperty(CalendarSkin.HOVERED_CELL_TEXT_COLOR));
    hoveredCellFillColorComponent.setColor(calendarComponent.getCalendarSkin().getColorSkinProperty(CalendarSkin.HOVERED_CELL_FILL_COLOR));
    weekTextColorComponent.setColor(calendarComponent.getCalendarSkin().getColorSkinProperty(CalendarSkin.WEEK_CELL_TEXT_COLOR));
    weekFillColorComponent.setColor(calendarComponent.getCalendarSkin().getColorSkinProperty(CalendarSkin.WEEK_CELL_FILL_COLOR));
    statusPanelTextColorComponent.setColor(calendarComponent.getCalendarSkin().getColorSkinProperty(CalendarSkin.STATUS_PANEL_TEXT_COLOR));
    statusPanelHoveredTextColorComponent.setColor(calendarComponent.getCalendarSkin().getColorSkinProperty(CalendarSkin.STATUS_PANEL_HOVERED_TEXT_COLOR));
    statusPanelFillColorComponent.setColor(calendarComponent.getCalendarSkin().getColorSkinProperty(CalendarSkin.STATUS_PANEL_FILL_COLOR));
    
    cellFontComponent.setFont(calendarComponent.getCalendarSkin().getFontSkinProperty(CalendarSkin.CELL_FONT));
    calendarComponent.getCalendarSkin().setSkinProperty(CalendarSkin.CELL_FONT, cellFontComponent.getFont());
    
    weekendCellFontComponent.setFont(calendarComponent.getCalendarSkin().getFontSkinProperty(CalendarSkin.WEEKEND_CELL_FONT));
    calendarComponent.getCalendarSkin().setSkinProperty(CalendarSkin.WEEKEND_CELL_FONT, weekendCellFontComponent.getFont());
    
    extraMonthCellFontComponent.setFont(calendarComponent.getCalendarSkin().getFontSkinProperty(CalendarSkin.EXTRA_MONTH_CELL_FONT));
    calendarComponent.getCalendarSkin().setSkinProperty(CalendarSkin.EXTRA_MONTH_CELL_FONT, extraMonthCellFontComponent.getFont());
    
    headerFontComponent.setFont(calendarComponent.getCalendarSkin().getFontSkinProperty(CalendarSkin.HEADER_CELL_FONT));
    calendarComponent.getCalendarSkin().setSkinProperty(CalendarSkin.HEADER_CELL_FONT, headerFontComponent.getFont());
    
    weekFontComponent.setFont(calendarComponent.getCalendarSkin().getFontSkinProperty(CalendarSkin.WEEK_CELL_FONT));
    calendarComponent.getCalendarSkin().setSkinProperty(CalendarSkin.WEEK_CELL_FONT, weekFontComponent.getFont());
    
    statusPanelFontComponent.setFont(calendarComponent.getCalendarSkin().getFontSkinProperty(CalendarSkin.STATUS_PANEL_FONT));
    calendarComponent.getCalendarSkin().setSkinProperty(CalendarSkin.STATUS_PANEL_FONT, statusPanelFontComponent.getFont());
    
  }

  public String getTitle() {
    return "Skin Editor";
  }
  
}
