
package com.imagine.component.calendar.demo.panels.skineditor;

import java.awt.*;
import java.awt.event.*;

import javax.swing.*;


public abstract class FontComponent extends JPanel {
  
  private Font font = super.getFont();
  private JLabel fontLabel = new JLabel();
  private JComboBox fontsComboBox = null;
  private JComboBox fontsStylesComboBox = null;
  Font[] fonts = new Font[0];
  Integer[] fontStylesCodes = new Integer[] {
      new Integer(Font.PLAIN),
      new Integer(Font.ITALIC),
      new Integer(Font.BOLD),
      new Integer(Font.ITALIC | Font.BOLD),
  };
  
  String[] fontStylesNames = new String[] {
      "PLAIN",
      "ITALIC",
      "BOLD",
      "ITALIC AND BOLD",
  };
  int selectedFontStyleIndex = 0;
  int selectedFontIndex = 0;
  int fontSize = 10;
    
  boolean initialized = false;

  public FontComponent() {
    initialize();
  }

  private void initialize() {
    String[] fontsNamesList = GraphicsEnvironment.getLocalGraphicsEnvironment().getAvailableFontFamilyNames();
    fonts = new Font[fontsNamesList.length];
    for (int i = 0; i < fontsNamesList.length; i++) {
      fonts[i] = new Font(fontsNamesList[i], Font.PLAIN, fontSize);
    }
    fontsComboBox = new JComboBox(fonts);
    
    fontsStylesComboBox = new JComboBox(fontStylesNames);
    
    this.setLayout(new GridLayout(1, 4, 5, 0));
    this.add(fontLabel);
    this.add(fontsComboBox);
    this.add(fontsStylesComboBox);
    
    fontsComboBox.addItemListener(new ItemListener() {
      public void itemStateChanged(ItemEvent itemEvent) {
        if (itemEvent.getStateChange() == ItemEvent.SELECTED) {
          JComboBox source = ((JComboBox)itemEvent.getSource());
          int selectedIndex = source.getSelectedIndex();
          if (selectedIndex < 0 || selectedIndex >= source.getItemCount()) {
            selectedIndex = 0;
          }
          
          selectedFontIndex = selectedIndex;
          int fontStyle = fontStylesCodes[selectedFontStyleIndex].intValue();
          Font currentFont = fonts[selectedFontIndex];
          font = new Font(currentFont.getFamily(), fontStyle, fontSize);
          
          updateValue();
        }
      }
    });
    fontsComboBox.setRenderer(new DefaultListCellRenderer() {
      public Component getListCellRendererComponent(JList list, Object value, int index, boolean isSelected, boolean cellHasFocus) {
        Component label = super.getListCellRendererComponent(list, value, index, isSelected, cellHasFocus);
        
        Font currentFont = (Font)value;
        label.setFont(currentFont);
        if (value != null) {
          setText(currentFont.getFamily());
        }
        
        return label;
      }
    });
    
    fontsStylesComboBox.addItemListener(new ItemListener() {
      public void itemStateChanged(ItemEvent itemEvent) {
        if (itemEvent.getStateChange() == ItemEvent.SELECTED) {
          JComboBox source = ((JComboBox)itemEvent.getSource());
          int selectedIndex = source.getSelectedIndex();
          if (selectedIndex < 0 || selectedIndex >= source.getItemCount()) {
            selectedIndex = 0;
          }
          
          selectedFontStyleIndex = selectedIndex;
          int fontStyle = fontStylesCodes[selectedFontStyleIndex].intValue();
          Font currentFont = fonts[selectedFontIndex];
          font = new Font(currentFont.getFamily(), fontStyle, fontSize);
          
          updateValue();
        }
      }
    });
    initialized = true;
  }
  
  public void setLabel(String labelText) {
    fontLabel.setText(labelText);
  }
  
  public Font getFont() {
    return font;
  }
  
  public void setFont(Font font) {
    if (font == null) {
      return;
    }
    if (initialized) {
      fontSize = font.getSize();
      
      int selectedIndex = 0;
      for (int i = 0; i < fonts.length; i++) {
        if (fonts[i].getFamily().equalsIgnoreCase(font.getFamily())) {
          selectedIndex = i;
          break;
        }
      }
      selectedFontIndex = selectedIndex;
      fontsComboBox.setSelectedIndex(selectedFontIndex);
      Font selectedFont = (Font)fontsComboBox.getItemAt(selectedFontIndex);
      
      for (int i = 0; i < fontStylesCodes.length; i++) {
        if (fontStylesCodes[i].intValue() == font.getStyle()) {
          selectedIndex = i;
          break;
        }
      }
      selectedFontStyleIndex = selectedIndex;
      fontsStylesComboBox.setSelectedIndex(selectedFontStyleIndex);
      this.font = new Font(selectedFont.getFamily(), fontStylesCodes[selectedFontStyleIndex].intValue(), fontSize);
    }
  }
  
  public abstract void updateValue() ;

}
