package com.imagine.component.calendar.renderers;

import java.util.*;

import com.imagine.component.calendar.CalendarComponent;
import com.imagine.component.calendar.data.*;
import com.imagine.component.calendar.renderers.backgroundrenderers.*;
import com.imagine.component.calendar.renderers.headercellrenderers.*;
import com.imagine.component.calendar.renderers.statuspanelrenderers.*;
import com.imagine.component.calendar.renderers.tablecellrenderers.*;
import com.imagine.component.calendar.renderers.weekcellrenderers.*;
import com.imagine.component.calendar.skins.CalendarSkin;

/**
 * Define an provider that displays with the hovered colors the cells from the line and column at which intersection is the hovered cell.
 */
public class CalendarRendererProviderHoveredIntersection extends CalendarRendererProvider {
  
  private GregorianCalendar calendar = new GregorianCalendar();
  
  private CalendarTableCellRenderer calendarTableCellRendererHovered = new CalendarTableCellRendererHoveredRect();
  private CalendarTableCellRenderer calendarTableCellRendererHoveredHighlighted = new CalendarTableCellRendererHoveredHighlighted();
  private CalendarTableCellRenderer calendarTableCellRendererExtraMonth = new CalendarTableCellRendererExtraMonth();
  private CalendarTableCellRenderer calendarTableCellRendererToday = new CalendarTableCellRendererToday();
  private CalendarTableCellRenderer calendarTableCellRendererSelected = new CalendarTableCellRendererSelectedRect();
  private CalendarTableCellRenderer calendarTableCellRendererWeekend = new CalendarTableCellRendererWeekend();
  private CalendarTableCellRenderer calendarTableCellRendererDefault = new CalendarTableCellRendererDefault();
  
  private CalendarHeaderCellRenderer calendarHeaderCellRendererDefault = new CalendarHeaderCellRendererDefault();
  private CalendarHeaderCellRenderer calendarHeaderCellRendererHoveredRect = new CalendarHeaderCellRendererHoveredHighlighted();
  
  private CalendarWeekCellRenderer calendarWeekCellRendererDefault = new CalendarWeekCellRendererDefault();
  private CalendarWeekCellRenderer calendarWeekCellRendererHoveredRect = new CalendarWeekCellRendererHoveredRect();
  private CalendarBackgroundRenderer calendarBackgroundRendererDefault = new CalendarBackgroundRendererDefault();
  
  private CalendarStatusPanelRenderer calendarStatusPanelRendererDefault = new CalendarStatusPanelRendererDefault();
  
  /**
   * @inheritDoc
   */
  public CalendarTableCellRenderer getTableCellRenderer(CalendarTableCellInfo calendarTableCellInfo) {
    if (calendarTableCellInfo.getMonthType() != CalendarMonthType.CURRENT_MONTH) {
      if (calendarComponent.getBooleanCalendarProperty(CalendarComponent.SHOW_EXTRA_MONTH_DAYS).booleanValue()) {
        if (calendarComponent.getBooleanCalendarProperty(CalendarComponent.SHOW_HOVER).booleanValue()) {
          if (calendarTableCellInfo.isOnHoveredRow() || calendarTableCellInfo.isOnHoveredColumn() ) {
            if (calendarTableCellInfo.isHovered()) {
              return calendarTableCellRendererHoveredHighlighted;
            } else {
              return calendarTableCellRendererHovered;
            }
          }
        }
        if (calendarTableCellInfo.isSelected()) {
        	return calendarTableCellRendererSelected;
        }
      }
      return calendarTableCellRendererExtraMonth;
    }
    
    if (calendarComponent.getBooleanCalendarProperty(CalendarComponent.SHOW_HOVER).booleanValue()) {
      if (calendarTableCellInfo.isOnHoveredRow() || calendarTableCellInfo.isOnHoveredColumn() ) {
        if (calendarTableCellInfo.isHovered()) {
          return calendarTableCellRendererHoveredHighlighted;
        } else {
          return calendarTableCellRendererHovered;
        }
      }
    }
    
    calendar.setTimeInMillis(System.currentTimeMillis());
    if (calendar.get(Calendar.YEAR) == calendarTableCellInfo.getYear() && 
        calendar.get(Calendar.MONTH) == calendarTableCellInfo.getMonth() &&        
        calendar.get(Calendar.DAY_OF_MONTH) == calendarTableCellInfo.getDayOfMonth()        
    ) {
      return calendarTableCellRendererToday;
    }
    
    if (calendarTableCellInfo.isSelected()) {
      return calendarTableCellRendererSelected;
    }
    
    if (calendarTableCellInfo.isFromWeekend()) {
      return calendarTableCellRendererWeekend;
    }
    
    return calendarTableCellRendererDefault;
  }
  
  
  
  /**
   * @inheritDoc
   */
  public CalendarWeekCellRenderer getWeekCellRenderer(CalendarWeekCellInfo calendarWeekCellInfo) {
    if (calendarWeekCellInfo.isOnHoveredRow()) {
      return calendarWeekCellRendererHoveredRect;
    }
    return calendarWeekCellRendererDefault;
  }
  
  /**
   * @inheritDoc
   */
  public CalendarHeaderCellRenderer getHeaderCellRenderer(CalendarHeaderCellInfo calendarHeaderCellInfo) {
    if (calendarHeaderCellInfo.isOnHoveredColumn()) {
      return calendarHeaderCellRendererHoveredRect;
    }
    return calendarHeaderCellRendererDefault;
  }
  
  /**
   * @inheritDoc
   */
  public CalendarBackgroundRenderer getBackgroundRenderer(CalendarBackgroundInfo calendarBackgroundInfo) {
    if (calendarComponent.getCalendarSkin().getImageSkinProperty(CalendarSkin.BACKGROUND_IMAGE) != null) {
      return calendarBackgroundRendererDefault;
    }
    return null;
  }
  
  /**
   * @inheritDoc
   */
  public boolean hasBackgroundRenderer() {
    if (calendarComponent.getCalendarSkin().getImageSkinProperty(CalendarSkin.BACKGROUND_IMAGE) != null) {
      return true;
    }
    return false;
  }
  
  /**
   * @inheritDoc
   */
  public String getName() {
    return "Hovered Intersection";
  }

  /**
   * @inheritDoc
   */
  public CalendarStatusPanelRenderer getStatusPanelRenderer(CalendarStatusPanelInfo calendarStatusPanelInfo) {
	  return calendarStatusPanelRendererDefault;
  }
}
