package com.imagine.component.calendar.renderers;

import java.util.*;

import com.imagine.component.calendar.CalendarComponent;
import com.imagine.component.calendar.data.*;
import com.imagine.component.calendar.renderers.backgroundrenderers.*;
import com.imagine.component.calendar.renderers.headercellrenderers.*;
import com.imagine.component.calendar.renderers.statuspanelrenderers.*;
import com.imagine.component.calendar.renderers.tablecellrenderers.*;
import com.imagine.component.calendar.renderers.weekcellrenderers.*;
import com.imagine.component.calendar.skins.CalendarSkin;

/**
 * Define an RoundRect renderer provider.
 */
public class CalendarRendererProviderRoundRect extends CalendarRendererProvider {
  
  private GregorianCalendar calendar = new GregorianCalendar();
  
  private CalendarTableCellRenderer calendarTableCellRendererHovered = new CalendarTableCellRendererHoveredRoundRect();
  private CalendarTableCellRenderer calendarTableCellRendererExtraMonth = new CalendarTableCellRendererExtraMonth();
  private CalendarTableCellRenderer calendarTableCellRendererToday = new CalendarTableCellRendererToday();
  private CalendarTableCellRenderer calendarTableCellRendererSelected = new CalendarTableCellRendererSelectedRoundRect();
  private CalendarTableCellRenderer calendarTableCellRendererWeekend = new CalendarTableCellRendererWeekend();
  private CalendarTableCellRenderer calendarTableCellRendererDefault = new CalendarTableCellRendererDefault();
  
  private CalendarHeaderCellRenderer calendarHeaderCellRendererDefault = new CalendarHeaderCellRendererDefault();
  private CalendarWeekCellRenderer calendarWeekCellRendererDefault = new CalendarWeekCellRendererDefault();
  private CalendarBackgroundRenderer calendarBackgroundRendererDefault = new CalendarBackgroundRendererDefault();
  
  private CalendarStatusPanelRenderer calendarStatusPanelRendererDefault = new CalendarStatusPanelRendererDefault();
  
  /**
   * @inheritDoc
   */
  public CalendarTableCellRenderer getTableCellRenderer(CalendarTableCellInfo calendarTableCellInfo) {
    if (calendarTableCellInfo.getMonthType() != CalendarMonthType.CURRENT_MONTH) {
      if (calendarComponent.getBooleanCalendarProperty(CalendarComponent.SHOW_EXTRA_MONTH_DAYS).booleanValue()) {
        if (calendarComponent.getBooleanCalendarProperty(CalendarComponent.SHOW_HOVER).booleanValue() && calendarTableCellInfo.isHovered()) {
          return calendarTableCellRendererHovered;
        }
      }
      if (calendarTableCellInfo.isSelected()) {
      	return calendarTableCellRendererSelected;
      }
      return calendarTableCellRendererExtraMonth;
    }
    
    if (calendarComponent.getBooleanCalendarProperty(CalendarComponent.SHOW_HOVER).booleanValue() && calendarTableCellInfo.isHovered()) {
      return calendarTableCellRendererHovered;
    }
    
    calendar.setTimeInMillis(System.currentTimeMillis());
    if (calendar.get(Calendar.YEAR) == calendarTableCellInfo.getYear() && 
        calendar.get(Calendar.MONTH) == calendarTableCellInfo.getMonth() &&        
        calendar.get(Calendar.DAY_OF_MONTH) == calendarTableCellInfo.getDayOfMonth()        
    ) {
      return calendarTableCellRendererToday;
    }
    
    if (calendarTableCellInfo.isSelected()) {
      return calendarTableCellRendererSelected;
    }
    
    if (calendarTableCellInfo.isFromWeekend()) {
      return calendarTableCellRendererWeekend;
    }
    
    return calendarTableCellRendererDefault;
  }

  
  /**
   * @inheritDoc
   */
  public CalendarWeekCellRenderer getWeekCellRenderer(CalendarWeekCellInfo calendarWeekCellInfo) {
    return calendarWeekCellRendererDefault;
  }
  
  /**
   * @inheritDoc
   */
  public CalendarHeaderCellRenderer getHeaderCellRenderer(CalendarHeaderCellInfo calendarHeaderCellInfo) {
    return calendarHeaderCellRendererDefault;
  }
  
  /**
   * @inheritDoc
   */
  public CalendarBackgroundRenderer getBackgroundRenderer(CalendarBackgroundInfo calendarBackgroundInfo) {
    if (calendarComponent.getCalendarSkin().getImageSkinProperty(CalendarSkin.BACKGROUND_IMAGE) != null) {
      return calendarBackgroundRendererDefault;
    }
    return null;
  }
    
  /**
   * @inheritDoc
   */
  public boolean hasBackgroundRenderer() {
    if (calendarComponent.getCalendarSkin().getImageSkinProperty(CalendarSkin.BACKGROUND_IMAGE) != null) {
      return true;
    }
    return false;
  }
  
  /**
   * @inheritDoc
   */
  public String getName() {
    return "RoundRect";
  }
  
  /**
   * @inheritDoc
   */
  public CalendarStatusPanelRenderer getStatusPanelRenderer(CalendarStatusPanelInfo calendarStatusPanelInfo) {
	  return calendarStatusPanelRendererDefault;
  }
}
